@@ -135,19 +135,6 @@ Mixer* Mixer::findMixer( const QString& mixer_id)
 }
 
 
-///**
-// * Set the card instance. Usually this will be 1, but if there is
-// * more than one card with the same name install, then you need
-// * to use 2, 3, ...
-// */
-//void Mixer::setCardInstance(int cardInstance)
-//{
-//    _cardInstance = cardInstance;
-//    recreateId();
-//    // DBusMixerWrapper must be called after recreateId(), as it uses the id
-//    new DBusMixerWrapper(this, dbusPath());
-//}
-
 /**
  * Set the final ID of this Mixer.
  * <br>Warning: This method is VERY fragile, because it is requires information that we have very late,
@@ -180,7 +167,7 @@ void Mixer::recreateId()
     primaryKeyOfMixer.replace(' ','_');
     primaryKeyOfMixer.replace('=','_');
     _id = primaryKeyOfMixer;
-	kDebug() << "Early _id=" << _id;
+//	kDebug() << "Early _id=" << _id;
 }
 
 const QString Mixer::dbusPath()
@@ -189,14 +176,20 @@ const QString Mixer::dbusPath()
 	// So once the first MixDevice is created, this must return the correct value
 	if (_id.isEmpty())
 	{
-		// Bug 308014: This a rather dirty hack, but it will guarantee that _id is definitely set.
-		// Even the _cardInstance is set at default value during construction of the MixDevice instances
+		if (! _mixerBackend->_cardRegistered)
+		{
+			// Bug 308014: By checking _cardRegistered, we can be sure that everything is fine, including the fact that
+			// the cardId (aka "card instance") is set. If _cardRegistered would be false, we will create potentially
+			// wrong/duplicated DBUS Paths here.
+			kWarning() << "Mixer id was empty when ceating DBUS path. Emergency code created the id=" <<_id;
+		}
+		// Bug 308014: Actually this a shortcut (you could also call it a hack). It would likely better if registerCard()
+		//             would create the Id, but it requires cooperation from ALL backends. Also Mixer->getId() would need to
+		//             proxy that to the backend.
+		// So for now we lazily create the MixerId here, while creating the first MixDevice for that card.
 		recreateId();
 	}
 
-//	kDebug() << "Late _id=" << _id;
-//	kDebug() << "handMade=" << QString("/Mixers/" +  getDriverName() + "." + _mixerBackend->getId()).replace(" ", "x").replace(".", "_");
-
 	// mixerName may contain arbitrary characters, so replace all that are not allowed to be be part of a DBUS path
 	QString cardPath = _id;
 	cardPath.replace(QRegExp("[^a-zA-Z0-9_]"), "_");
@@ -212,6 +205,10 @@ void Mixer::volumeSave( KConfig *config )
     QString grp("Mixer");
     grp.append(id());
     _mixerBackend->m_mixDevices.write( config, grp );
+
+    // This might not be the standard application config object
+    // => Better be safe and call sync().
+    config->sync();
 }
 
 void Mixer::volumeLoad( KConfig *config )
@@ -278,6 +275,8 @@ bool Mixer::openIfValid()
         {
             if ( !m_dynamic )
                 kError(67100) << "Mixer::open() no master detected." << endl;
+            else
+                kDebug(67100) << "Mixer::open() no master detected." << endl;
             QString noMaster = "---no-master-detected---";
             setLocalMasterMD(noMaster); // no master
         }
@@ -346,11 +345,6 @@ QString Mixer::translateKernelToWhatsthis(const QString &kernelName)
 
 /* ------- WRAPPER METHODS. END -------------------------------- */
 
-void Mixer::setBeepOnVolumeChange(bool beepOnVolumeChange)
-{
-	m_beepOnVolumeChange = beepOnVolumeChange;
-}
-
 int Mixer::balance() const {
     return m_balance;
 }
@@ -510,16 +504,25 @@ Mixer* Mixer::getGlobalMasterMixer()
  * Return the preferred global master.
  * If there is no preferred global master, returns the current master instead.
  */
-MasterControl& Mixer::getGlobalMasterPreferred()
+MasterControl& Mixer::getGlobalMasterPreferred(bool fallbackAllowed)
 {
-    if ( _globalMasterPreferred.isValid() ) {
+    static MasterControl result;
+
+    if ( !fallbackAllowed || _globalMasterPreferred.isValid() ) {
         kDebug() << "Returning preferred master";
         return _globalMasterPreferred;
     }
-    else {
-        kDebug() << "Returning current master";
-        return _globalMasterCurrent;
+
+    Mixer* mm = Mixer::getGlobalMasterMixerNoFalback();
+    if (mm) {
+        result.set(_globalMasterPreferred.getCard(), mm->getRecommendedDeviceId());
+        if (!result.getControl().isEmpty())
+            kDebug() << "Returning extended preferred master";
+            return result;
     }
+
+    kDebug() << "Returning current master";
+    return _globalMasterCurrent;
 }
 
 
@@ -539,6 +542,12 @@ shared_ptr<MixDevice> Mixer::getGlobalMasterMD(bool fallbackAllowed)
 	if ( mixer == 0 )
 		return mdRet;
 
+	if (_globalMasterCurrent.getControl().isEmpty())
+	{
+		// Default (recommended) control
+		return mixer->_mixerBackend->recommendedMaster();
+	}
+
 	foreach (shared_ptr<MixDevice> md, mixer->_mixerBackend->m_mixDevices )
 	{
 		if ( md.get() == 0 )
@@ -562,12 +571,21 @@ shared_ptr<MixDevice> Mixer::getGlobalMasterMD(bool fallbackAllowed)
 	return mdRet;
 }
 
-
-
+QString Mixer::getRecommendedDeviceId()
+{
+    if ( _mixerBackend != 0 ) {
+        shared_ptr<MixDevice> recommendedMaster = _mixerBackend->recommendedMaster();
+        if ( recommendedMaster.get() != 0 )
+            return recommendedMaster->id();
+    }
+    return QString();
+}
 
 shared_ptr<MixDevice> Mixer::getLocalMasterMD()
 {
-  return find( _masterDevicePK );
+    if (_mixerBackend && _masterDevicePK.isEmpty())
+        return _mixerBackend->recommendedMaster();
+    return find( _masterDevicePK );
 }
 
 void Mixer::setLocalMasterMD(QString &devPK)
